package org.apache.bcel.classfile;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.classfile.Attribute;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.classfile.Visitor;

public final class PMGClass extends Attribute {
  private int pmgClassIndex;
  
  private int pmgIndex;
  
  PMGClass(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
    this(nameIndex, length, input.readUnsignedShort(), input.readUnsignedShort(), constantPool);
  }
  
  public PMGClass(int nameIndex, int length, int pmgIndex, int pmgClassIndex, ConstantPool constantPool) {
    super((byte)9, nameIndex, length, constantPool);
    this.pmgIndex = pmgIndex;
    this.pmgClassIndex = pmgClassIndex;
  }
  
  public PMGClass(org.apache.bcel.classfile.PMGClass pgmClass) {
    this(pgmClass.getNameIndex(), pgmClass.getLength(), pgmClass.getPMGIndex(), pgmClass.getPMGClassIndex(), pgmClass.getConstantPool());
  }
  
  public void accept(Visitor v) {
    println("Visiting non-standard PMGClass object");
  }
  
  public Attribute copy(ConstantPool constantPool) {
    return (Attribute)clone();
  }
  
  public void dump(DataOutputStream file) throws IOException {
    super.dump(file);
    file.writeShort(this.pmgIndex);
    file.writeShort(this.pmgClassIndex);
  }
  
  public int getPMGClassIndex() {
    return this.pmgClassIndex;
  }
  
  public String getPMGClassName() {
    return getConstantPool().getConstantUtf8(this.pmgClassIndex).getBytes();
  }
  
  public int getPMGIndex() {
    return this.pmgIndex;
  }
  
  public String getPMGName() {
    return getConstantPool().getConstantUtf8(this.pmgIndex).getBytes();
  }
  
  public void setPMGClassIndex(int pmgClassIndex) {
    this.pmgClassIndex = pmgClassIndex;
  }
  
  public void setPMGIndex(int pmgIndex) {
    this.pmgIndex = pmgIndex;
  }
  
  public String toString() {
    return "PMGClass(" + getPMGName() + ", " + getPMGClassName() + ")";
  }
}
